Pikaday - weeknumbers example
Author: Maxime Thirouin

# Pikaday - showing weeknumbers

A refreshing JavaScript Datepicker — lightweight, no dependencies, modular CSS.

Date:

## What is this?

Since version 1.0 Pikaday is a stable and battle tested date-picker. Feel free to use it however you like but please report any bugs or feature requests to the GitHub issue tracker, thanks!

Copyright © 2014 David Bushell | BSD & MIT license | Example by Ramiro Rikkert